@@ -1172,59 +1172,84 @@
         }
     );
 
-    var MessageType;
-    (function (MessageType) {
-        MessageType["UI_GET_DATA"] = "ui-get-data";
-        MessageType["UI_GET_DEVTOOLS_DATA"] = "ui-get-devtools-data";
-        MessageType["UI_SUBSCRIBE_TO_CHANGES"] = "ui-subscribe-to-changes";
-        MessageType["UI_UNSUBSCRIBE_FROM_CHANGES"] =
-            "ui-unsubscribe-from-changes";
-        MessageType["UI_CHANGE_SETTINGS"] = "ui-change-settings";
-        MessageType["UI_SET_THEME"] = "ui-set-theme";
-        MessageType["UI_TOGGLE_ACTIVE_TAB"] = "ui-toggle-active-tab";
-        MessageType["UI_MARK_NEWS_AS_READ"] = "ui-mark-news-as-read";
-        MessageType["UI_MARK_NEWS_AS_DISPLAYED"] = "ui-mark-news-as-displayed";
-        MessageType["UI_LOAD_CONFIG"] = "ui-load-config";
-        MessageType["UI_APPLY_DEV_DYNAMIC_THEME_FIXES"] =
-            "ui-apply-dev-dynamic-theme-fixes";
-        MessageType["UI_RESET_DEV_DYNAMIC_THEME_FIXES"] =
-            "ui-reset-dev-dynamic-theme-fixes";
-        MessageType["UI_APPLY_DEV_INVERSION_FIXES"] =
-            "ui-apply-dev-inversion-fixes";
-        MessageType["UI_RESET_DEV_INVERSION_FIXES"] =
-            "ui-reset-dev-inversion-fixes";
-        MessageType["UI_APPLY_DEV_STATIC_THEMES"] =
-            "ui-apply-dev-static-themes";
-        MessageType["UI_RESET_DEV_STATIC_THEMES"] =
-            "ui-reset-dev-static-themes";
-        MessageType["UI_SAVE_FILE"] = "ui-save-file";
-        MessageType["UI_REQUEST_EXPORT_CSS"] = "ui-request-export-css";
-        MessageType["UI_COLOR_SCHEME_CHANGE"] = "ui-color-scheme-change";
-        MessageType["UI_HIDE_HIGHLIGHTS"] = "ui-hide-highlights";
-        MessageType["BG_CHANGES"] = "bg-changes";
-        MessageType["BG_ADD_CSS_FILTER"] = "bg-add-css-filter";
-        MessageType["BG_ADD_STATIC_THEME"] = "bg-add-static-theme";
-        MessageType["BG_ADD_SVG_FILTER"] = "bg-add-svg-filter";
-        MessageType["BG_ADD_DYNAMIC_THEME"] = "bg-add-dynamic-theme";
-        MessageType["BG_EXPORT_CSS"] = "bg-export-css";
-        MessageType["BG_UNSUPPORTED_SENDER"] = "bg-unsupported-sender";
-        MessageType["BG_CLEAN_UP"] = "bg-clean-up";
-        MessageType["BG_RELOAD"] = "bg-reload";
-        MessageType["BG_FETCH_RESPONSE"] = "bg-fetch-response";
-        MessageType["BG_UI_UPDATE"] = "bg-ui-update";
-        MessageType["BG_CSS_UPDATE"] = "bg-css-update";
-        MessageType["CS_COLOR_SCHEME_CHANGE"] = "cs-color-scheme-change";
-        MessageType["CS_FRAME_CONNECT"] = "cs-frame-connect";
-        MessageType["CS_FRAME_FORGET"] = "cs-frame-forget";
-        MessageType["CS_FRAME_FREEZE"] = "cs-frame-freeze";
-        MessageType["CS_FRAME_RESUME"] = "cs-frame-resume";
-        MessageType["CS_EXPORT_CSS_RESPONSE"] = "cs-export-css-response";
-        MessageType["CS_FETCH"] = "cs-fetch";
-        MessageType["CS_DARK_THEME_DETECTED"] = "cs-dark-theme-detected";
-        MessageType["CS_DARK_THEME_NOT_DETECTED"] =
-            "cs-dark-theme-not-detected";
-        MessageType["CS_LOG"] = "cs-log";
-    })(MessageType || (MessageType = {}));
+    var MessageTypeUItoBG;
+    (function (MessageTypeUItoBG) {
+        MessageTypeUItoBG["GET_DATA"] = "ui-bg-get-data";
+        MessageTypeUItoBG["GET_DEVTOOLS_DATA"] = "ui-bg-get-devtools-data";
+        MessageTypeUItoBG["SUBSCRIBE_TO_CHANGES"] =
+            "ui-bg-subscribe-to-changes";
+        MessageTypeUItoBG["UNSUBSCRIBE_FROM_CHANGES"] =
+            "ui-bg-unsubscribe-from-changes";
+        MessageTypeUItoBG["CHANGE_SETTINGS"] = "ui-bg-change-settings";
+        MessageTypeUItoBG["SET_THEME"] = "ui-bg-set-theme";
+        MessageTypeUItoBG["TOGGLE_ACTIVE_TAB"] = "ui-bg-toggle-active-tab";
+        MessageTypeUItoBG["MARK_NEWS_AS_READ"] = "ui-bg-mark-news-as-read";
+        MessageTypeUItoBG["MARK_NEWS_AS_DISPLAYED"] =
+            "ui-bg-mark-news-as-displayed";
+        MessageTypeUItoBG["LOAD_CONFIG"] = "ui-bg-load-config";
+        MessageTypeUItoBG["APPLY_DEV_DYNAMIC_THEME_FIXES"] =
+            "ui-bg-apply-dev-dynamic-theme-fixes";
+        MessageTypeUItoBG["RESET_DEV_DYNAMIC_THEME_FIXES"] =
+            "ui-bg-reset-dev-dynamic-theme-fixes";
+        MessageTypeUItoBG["APPLY_DEV_INVERSION_FIXES"] =
+            "ui-bg-apply-dev-inversion-fixes";
+        MessageTypeUItoBG["RESET_DEV_INVERSION_FIXES"] =
+            "ui-bg-reset-dev-inversion-fixes";
+        MessageTypeUItoBG["APPLY_DEV_STATIC_THEMES"] =
+            "ui-bg-apply-dev-static-themes";
+        MessageTypeUItoBG["RESET_DEV_STATIC_THEMES"] =
+            "ui-bg-reset-dev-static-themes";
+        MessageTypeUItoBG["SAVE_FILE"] = "ui-bg-save-file";
+        MessageTypeUItoBG["COLOR_SCHEME_CHANGE"] = "ui-bg-color-scheme-change";
+        MessageTypeUItoBG["HIDE_HIGHLIGHTS"] = "ui-bg-hide-highlights";
+    })(MessageTypeUItoBG || (MessageTypeUItoBG = {}));
+    var MessageTypeBGtoUI;
+    (function (MessageTypeBGtoUI) {
+        MessageTypeBGtoUI["CHANGES"] = "bg-ui-changes";
+    })(MessageTypeBGtoUI || (MessageTypeBGtoUI = {}));
+    var DebugMessageTypeBGtoUI;
+    (function (DebugMessageTypeBGtoUI) {
+        DebugMessageTypeBGtoUI["CSS_UPDATE"] = "debug-bg-ui-css-update";
+        DebugMessageTypeBGtoUI["UPDATE"] = "debug-bg-ui-update";
+    })(DebugMessageTypeBGtoUI || (DebugMessageTypeBGtoUI = {}));
+    var MessageTypeBGtoCS;
+    (function (MessageTypeBGtoCS) {
+        MessageTypeBGtoCS["ADD_CSS_FILTER"] = "bg-cs-add-css-filter";
+        MessageTypeBGtoCS["ADD_DYNAMIC_THEME"] = "bg-cs-add-dynamic-theme";
+        MessageTypeBGtoCS["ADD_STATIC_THEME"] = "bg-cs-add-static-theme";
+        MessageTypeBGtoCS["ADD_SVG_FILTER"] = "bg-cs-add-svg-filter";
+        MessageTypeBGtoCS["CLEAN_UP"] = "bg-cs-clean-up";
+        MessageTypeBGtoCS["FETCH_RESPONSE"] = "bg-cs-fetch-response";
+        MessageTypeBGtoCS["UNSUPPORTED_SENDER"] = "bg-cs-unsupported-sender";
+    })(MessageTypeBGtoCS || (MessageTypeBGtoCS = {}));
+    var DebugMessageTypeBGtoCS;
+    (function (DebugMessageTypeBGtoCS) {
+        DebugMessageTypeBGtoCS["RELOAD"] = "debug-bg-cs-reload";
+    })(DebugMessageTypeBGtoCS || (DebugMessageTypeBGtoCS = {}));
+    var MessageTypeCStoBG;
+    (function (MessageTypeCStoBG) {
+        MessageTypeCStoBG["COLOR_SCHEME_CHANGE"] = "cs-bg-color-scheme-change";
+        MessageTypeCStoBG["DARK_THEME_DETECTED"] = "cs-bg-dark-theme-detected";
+        MessageTypeCStoBG["DARK_THEME_NOT_DETECTED"] =
+            "cs-bg-dark-theme-not-detected";
+        MessageTypeCStoBG["FETCH"] = "cs-bg-fetch";
+        MessageTypeCStoBG["DOCUMENT_CONNECT"] = "cs-bg-document-connect";
+        MessageTypeCStoBG["DOCUMENT_FORGET"] = "cs-bg-document-forget";
+        MessageTypeCStoBG["DOCUMENT_FREEZE"] = "cs-bg-document-freeze";
+        MessageTypeCStoBG["DOCUMENT_RESUME"] = "cs-bg-document-resume";
+    })(MessageTypeCStoBG || (MessageTypeCStoBG = {}));
+    var DebugMessageTypeCStoBG;
+    (function (DebugMessageTypeCStoBG) {
+        DebugMessageTypeCStoBG["LOG"] = "debug-cs-bg-log";
+    })(DebugMessageTypeCStoBG || (DebugMessageTypeCStoBG = {}));
+    var MessageTypeCStoUI;
+    (function (MessageTypeCStoUI) {
+        MessageTypeCStoUI["EXPORT_CSS_RESPONSE"] = "cs-ui-export-css-response";
+    })(MessageTypeCStoUI || (MessageTypeCStoUI = {}));
+    var MessageTypeUItoCS;
+    (function (MessageTypeUItoCS) {
+        MessageTypeUItoCS["EXPORT_CSS"] = "ui-cs-export-css";
+    })(MessageTypeUItoCS || (MessageTypeUItoCS = {}));
 
     const isNavigatorDefined = typeof navigator !== "undefined";
     const userAgent = isNavigatorDefined
@@ -2194,7 +2219,7 @@
             }
             store.isFocused = true;
             context.refresh();
-            window.addEventListener("mousedown", onOuterClick);
+            window.addEventListener("mousedown", onOuterClick, {passive: true});
         }
         function blur() {
             if (!store.isFocused) {
@@ -2295,12 +2320,16 @@
         if (!overlayNodes.has(key)) {
             const node = document.createElement("div");
             node.classList.add("overlay");
-            node.addEventListener("click", (e) => {
-                if (clickListeners.has(node) && e.currentTarget === node) {
-                    const listener = clickListeners.get(node);
-                    listener();
-                }
-            });
+            node.addEventListener(
+                "click",
+                (e) => {
+                    if (clickListeners.has(node) && e.currentTarget === node) {
+                        const listener = clickListeners.get(node);
+                        listener();
+                    }
+                },
+                {passive: true}
+            );
             overlayNodes.set(key, node);
         }
         return overlayNodes.get(key);
@@ -2552,7 +2581,7 @@
     class Connector {
         constructor() {
             this.onChangesReceived = ({type, data}) => {
-                if (type === MessageType.BG_CHANGES) {
+                if (type === MessageTypeBGtoUI.CHANGES) {
                     this.changeSubscribers.forEach((callback) =>
                         callback(data)
                     );
@@ -2587,17 +2616,17 @@
             });
         }
         async getData() {
-            return await this.sendRequest(MessageType.UI_GET_DATA);
+            return await this.sendRequest(MessageTypeUItoBG.GET_DATA);
         }
         async getDevToolsData() {
-            return await this.sendRequest(MessageType.UI_GET_DEVTOOLS_DATA);
+            return await this.sendRequest(MessageTypeUItoBG.GET_DEVTOOLS_DATA);
         }
         subscribeToChanges(callback) {
             this.changeSubscribers.add(callback);
             if (this.changeSubscribers.size === 1) {
                 chrome.runtime.onMessage.addListener(this.onChangesReceived);
                 chrome.runtime.sendMessage({
-                    type: MessageType.UI_SUBSCRIBE_TO_CHANGES
+                    type: MessageTypeUItoBG.SUBSCRIBE_TO_CHANGES
                 });
             }
         }
@@ -2606,76 +2635,76 @@
         }
         changeSettings(settings) {
             chrome.runtime.sendMessage({
-                type: MessageType.UI_CHANGE_SETTINGS,
+                type: MessageTypeUItoBG.CHANGE_SETTINGS,
                 data: settings
             });
         }
         setTheme(theme) {
             chrome.runtime.sendMessage({
-                type: MessageType.UI_SET_THEME,
+                type: MessageTypeUItoBG.SET_THEME,
                 data: theme
             });
         }
         toggleActiveTab() {
             chrome.runtime.sendMessage({
-                type: MessageType.UI_TOGGLE_ACTIVE_TAB,
+                type: MessageTypeUItoBG.TOGGLE_ACTIVE_TAB,
                 data: {}
             });
         }
         markNewsAsRead(ids) {
             chrome.runtime.sendMessage({
-                type: MessageType.UI_MARK_NEWS_AS_READ,
+                type: MessageTypeUItoBG.MARK_NEWS_AS_READ,
                 data: ids
             });
         }
         markNewsAsDisplayed(ids) {
             chrome.runtime.sendMessage({
-                type: MessageType.UI_MARK_NEWS_AS_DISPLAYED,
+                type: MessageTypeUItoBG.MARK_NEWS_AS_DISPLAYED,
                 data: ids
             });
         }
         loadConfig(options) {
             chrome.runtime.sendMessage({
-                type: MessageType.UI_LOAD_CONFIG,
+                type: MessageTypeUItoBG.LOAD_CONFIG,
                 data: options
             });
         }
         async applyDevDynamicThemeFixes(text) {
             return await this.sendRequest(
-                MessageType.UI_APPLY_DEV_DYNAMIC_THEME_FIXES,
+                MessageTypeUItoBG.APPLY_DEV_DYNAMIC_THEME_FIXES,
                 text
             );
         }
         resetDevDynamicThemeFixes() {
             chrome.runtime.sendMessage({
-                type: MessageType.UI_RESET_DEV_DYNAMIC_THEME_FIXES
+                type: MessageTypeUItoBG.RESET_DEV_DYNAMIC_THEME_FIXES
             });
         }
         async applyDevInversionFixes(text) {
             return await this.sendRequest(
-                MessageType.UI_APPLY_DEV_INVERSION_FIXES,
+                MessageTypeUItoBG.APPLY_DEV_INVERSION_FIXES,
                 text
             );
         }
         resetDevInversionFixes() {
             chrome.runtime.sendMessage({
-                type: MessageType.UI_RESET_DEV_INVERSION_FIXES
+                type: MessageTypeUItoBG.RESET_DEV_INVERSION_FIXES
             });
         }
         async applyDevStaticThemes(text) {
             return await this.sendRequest(
-                MessageType.UI_APPLY_DEV_STATIC_THEMES,
+                MessageTypeUItoBG.APPLY_DEV_STATIC_THEMES,
                 text
             );
         }
         resetDevStaticThemes() {
             chrome.runtime.sendMessage({
-                type: MessageType.UI_RESET_DEV_STATIC_THEMES
+                type: MessageTypeUItoBG.RESET_DEV_STATIC_THEMES
             });
         }
         async hideHighlights(ids) {
             chrome.runtime.sendMessage({
-                type: MessageType.UI_HIDE_HIGHLIGHTS,
+                type: MessageTypeUItoBG.HIDE_HIGHLIGHTS,
                 data: ids
             });
         }
@@ -2684,7 +2713,7 @@
                 this.changeSubscribers.clear();
                 chrome.runtime.onMessage.removeListener(this.onChangesReceived);
                 chrome.runtime.sendMessage({
-                    type: MessageType.UI_UNSUBSCRIBE_FROM_CHANGES
+                    type: MessageTypeUItoBG.UNSUBSCRIBE_FROM_CHANGES
                 });
             }
         }
@@ -2695,7 +2724,9 @@
     }
     async function start() {
         const connector = new Connector();
-        window.addEventListener("unload", () => connector.disconnect());
+        window.addEventListener("unload", () => connector.disconnect(), {
+            passive: true
+        });
         const data = await connector.getData();
         renderBody(data, connector);
         connector.subscribeToChanges((data) => renderBody(data, connector));
